@@ -243,7 +243,7 @@ find_cb (GtkWidget  *widget,
 {
 	char *esc_path;
 
-	esc_path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (data->fd_start_from_filechooserbutton));
+	esc_path = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (data->fd_start_from_filechooserbutton));
 	data->start_from_path = gnome_vfs_unescape_string (esc_path, "");
 	g_free (esc_path);
 
@@ -1168,7 +1168,7 @@ check_image (DialogData *data,
 		ImageData *idata2 = scan->data;
 
 		if ((strcmp (idata->sum, idata2->sum) == 0)
-		    && (strcmp (idata->path, idata2->path) != 0)) {
+		    && ! same_uri (idata->path, idata2->path)) {
 			idata->common = idata2->common;
 			idata->common->ref++;
 			idata->common->duplicates++;
